import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';
import { globalRoutes, indexRoutes} from '@/router'

Vue.use(Router);

const router = new Router({
    routes: [
        {
            path: '/notifyindexview/:notifyindexview?',
            beforeEnter: (to: any, from: any, next: any) => {
                const routerParamsName = 'notifyindexview';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    Object.assign(params, qs.parse(to.params[routerParamsName], { delimiter: ';' }));
                }
                const url: string = '/appdata';
                const auth: Promise<any> = AuthGuard.getInstance().authGuard(url, params, router);
                auth.then(() => {
                    next();
                }).catch(() => {
                    next();
                });
            },
            meta: {  
                caption: 'app.views.notifyindexview.title',
                info:'',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'notifyindexview', parameterName: 'notifyindexview' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/notify/notify-index-view/notify-index-view.vue'),
            children: [
                {
                    path: 'msgtemplates/:msgtemplate?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.msgtemplate.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'notifyindexview', parameterName: 'notifyindexview' },
                            { pathName: 'msgtemplates', parameterName: 'msgtemplate' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/notify/msg-template-grid-view/msg-template-grid-view.vue'),
                },
                {
                    path: 'apiopenaccesses/:apiopenaccess?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.apiopenaccess.views.gridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'notifyindexview', parameterName: 'notifyindexview' },
                            { pathName: 'apiopenaccesses', parameterName: 'apiopenaccess' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/notify/api-open-access-grid-view/api-open-access-grid-view.vue'),
                },
                {
                    path: 'apiopenaccesses/:apiopenaccess?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.apiopenaccess.views.pickupview.title',
                        info:'',
                        parameters: [
                            { pathName: 'notifyindexview', parameterName: 'notifyindexview' },
                            { pathName: 'apiopenaccesses', parameterName: 'apiopenaccess' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/notify/api-open-access-pickup-view/api-open-access-pickup-view.vue'),
                },
                {
                    path: 'apiopenaccesses/:apiopenaccess?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.apiopenaccess.views.pickupgridview.title',
                        info:'',
                        parameters: [
                            { pathName: 'notifyindexview', parameterName: 'notifyindexview' },
                            { pathName: 'apiopenaccesses', parameterName: 'apiopenaccess' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/notify/api-open-access-pickup-grid-view/api-open-access-pickup-grid-view.vue'),
                },
                {
                    path: 'msgtemplates/:msgtemplate?/editview/:editview?',
                    meta: {
                        caption: 'entities.msgtemplate.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'notifyindexview', parameterName: 'notifyindexview' },
                            { pathName: 'msgtemplates', parameterName: 'msgtemplate' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/notify/msg-template-edit-view/msg-template-edit-view.vue'),
                },
                {
                    path: 'apiopenaccesses/:apiopenaccess?/editview/:editview?',
                    meta: {
                        caption: 'entities.apiopenaccess.views.editview.title',
                        info:'',
                        parameters: [
                            { pathName: 'notifyindexview', parameterName: 'notifyindexview' },
                            { pathName: 'apiopenaccesses', parameterName: 'apiopenaccess' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/notify/api-open-access-edit-view/api-open-access-edit-view.vue'),
                },
            ...indexRoutes,
            ],
        },
    {
        path: '/msgtemplates/:msgtemplate?/gridview/:gridview?',
        meta: {
            caption: 'entities.msgtemplate.views.gridview.title',
            info:'',
            parameters: [
                { pathName: 'msgtemplates', parameterName: 'msgtemplate' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/notify/msg-template-grid-view/msg-template-grid-view.vue'),
    },
    {
        path: '/apiopenaccesses/:apiopenaccess?/gridview/:gridview?',
        meta: {
            caption: 'entities.apiopenaccess.views.gridview.title',
            info:'',
            parameters: [
                { pathName: 'apiopenaccesses', parameterName: 'apiopenaccess' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/notify/api-open-access-grid-view/api-open-access-grid-view.vue'),
    },
    {
        path: '/apiopenaccesses/:apiopenaccess?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.apiopenaccess.views.pickupgridview.title',
            info:'',
            parameters: [
                { pathName: 'apiopenaccesses', parameterName: 'apiopenaccess' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/notify/api-open-access-pickup-grid-view/api-open-access-pickup-grid-view.vue'),
    },
    {
        path: '/apiopenaccesses/:apiopenaccess?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.apiopenaccess.views.pickupview.title',
            info:'',
            parameters: [
                { pathName: 'apiopenaccesses', parameterName: 'apiopenaccess' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/notify/api-open-access-pickup-view/api-open-access-pickup-view.vue'),
    },
    {
        path: '/apiopenaccesses/:apiopenaccess?/editview/:editview?',
        meta: {
            caption: 'entities.apiopenaccess.views.editview.title',
            info:'',
            parameters: [
                { pathName: 'apiopenaccesses', parameterName: 'apiopenaccess' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/notify/api-open-access-edit-view/api-open-access-edit-view.vue'),
    },
    {
        path: '/msgtemplates/:msgtemplate?/editview/:editview?',
        meta: {
            caption: 'entities.msgtemplate.views.editview.title',
            info:'',
            parameters: [
                { pathName: 'msgtemplates', parameterName: 'msgtemplate' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/notify/msg-template-edit-view/msg-template-edit-view.vue'),
    },
        ...globalRoutes,
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                router.app.$store.commit('resetRootStateData');
                next();
            },
            component: () => import('@components/login/login.vue'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'notifyindexview'
        },
    ],
});

export default router;
